@@ -5,11 +5,11 @@
 int sigaltstack(const stack_t *restrict ss, stack_t *restrict old)
 {
 	if (ss) {
-		if (ss->ss_size < MINSIGSTKSZ) {
+		if (!(ss->ss_flags & SS_DISABLE) && ss->ss_size < MINSIGSTKSZ) {
 			errno = ENOMEM;
 			return -1;
 		}
-		if (ss->ss_flags & ~SS_DISABLE) {
+		if (ss->ss_flags & SS_ONSTACK) {
 			errno = EINVAL;
 			return -1;
 		}
