@@ -1,7 +1,7 @@
 #include "pthread_impl.h"
 
-void __unmapself_sh_mmu(void *, size_t);
-void __unmapself_sh_nommu(void *, size_t);
+hidden void __unmapself_sh_mmu(void *, size_t);
+hidden void __unmapself_sh_nommu(void *, size_t);
 
 #if !defined(__SH3__) && !defined(__SH4__)
 #define __unmapself __unmapself_sh_nommu
@@ -12,7 +12,7 @@ void __unmapself_sh_nommu(void *, size_t);
 	: : "r"(pc), "r"(sp) : "r0", "memory" )
 #include "../__unmapself.c"
 #undef __unmapself
-extern __attribute__((__visibility__("hidden"))) unsigned __sh_nommu;
+extern hidden unsigned __sh_nommu;
 #else
 #define __sh_nommu 0
 #endif
